import { createError } from "h3";
import { GraphqlMiddlewareOperation } from "./../../settings/index.mjs";
export function queryParamToVariables(query) {
  try {
    if (query.__variables && typeof query.__variables === "string") {
      return JSON.parse(query.__variables);
    }
  } catch (_e) {
  }
  return query;
}
export function getEndpoint(moduleConfig, event, operation, operationName) {
  if (typeof moduleConfig.graphqlEndpoint === "string") {
    return moduleConfig.graphqlEndpoint;
  } else if (typeof moduleConfig.graphqlEndpoint === "function") {
    const endpoint = moduleConfig.graphqlEndpoint(
      event,
      operation,
      operationName
    );
    if (endpoint && typeof endpoint === "string") {
      return endpoint;
    }
  }
  throw new Error("Failed to determine endpoint for GraphQL server.");
}
export function getFetchOptions(moduleConfig, event, operation, operationName) {
  if (typeof moduleConfig.serverFetchOptions === "function") {
    return moduleConfig.serverFetchOptions(event, operation, operationName) || {};
  } else if (typeof moduleConfig.serverFetchOptions === "object") {
    return moduleConfig.serverFetchOptions;
  }
  return {};
}
function throwError(statusMessage, statusCode = 400) {
  throw createError({
    statusCode,
    statusMessage
  });
}
export function validateRequest(method, operation, name, documents) {
  if (method !== "POST" && method !== "GET") {
    throwError("Method not allowed.", 405);
  }
  if (operation !== GraphqlMiddlewareOperation.Query && operation !== GraphqlMiddlewareOperation.Mutation) {
    throwError("Unknown operation.");
  }
  if (method === "POST" && operation !== GraphqlMiddlewareOperation.Mutation) {
    throwError("Queries must be a GET request.");
  }
  if (method === "GET" && operation !== GraphqlMiddlewareOperation.Query) {
    throwError("Mutations must be a POST request.");
  }
  if (!name) {
    throwError("Missing name for operation.");
  }
  if (!documents) {
    throwError("Failed to load GraphQL documents", 500);
  }
  if (!documents[operation][name]) {
    throwError(`Operation "${operation}" with name "${name}" not found.`);
  }
}
